Changelog
=========


(unreleased)
------------
- Adding .typed file. [brahle]


0.2.2 (2023-04-10)
------------------
- Release: version 0.2.2 🚀 [brahle]
- Exposing some additional items. [brahle]


0.2.1 (2023-04-10)
------------------
- Release: version 0.2.1 🚀 [brahle]
- Fixing the formatting. [brahle]


0.2.0 (2023-04-10)
------------------
- Release: version 0.2.0 🚀 [brahle]
- Edit (#7) [Bruno Rahle]


0.1.1 (2023-04-10)
------------------
- Release: version 0.1.1 🚀 [brahle]
- Release: version 0.1.0 🚀 [brahle]
- Merge branch 'main' of github.com:brahle/brds into main. [brahle]
- Br/updates (#6) [Bruno Rahle]

  * Adding FastAPI app to show the datasets

  * Updates to the container


0.1.0 (2023-04-10)
------------------
- Release: version 0.1.0 🚀 [brahle]


0.0.5 (2023-02-18)
------------------
- Release: version 0.0.5 🚀 [brahle]
- Feat: Adding gunzip imporer (#5) [Bruno Rahle]


0.0.4 (2023-02-18)
------------------
- Release: version 0.0.4 🚀 [brahle]
- Updating version (#4) [Bruno Rahle]


0.0.3 (2023-02-18)
------------------
- Release: version 0.0.3 🚀 [brahle]
- Fixing the docs (#3) [Bruno Rahle]


0.0.2 (2023-02-18)
------------------

Fix
~~~
- Release (#2) [Bruno Rahle]

Other
~~~~~
- Release: version 0.0.2 🚀 [brahle]


0.0.1 (2023-02-18)
------------------
- Release: version 0.0.1 🚀 [brahle]
- Feat: Initial version (#1) [Bruno Rahle]

  * Initial version of the brds

  * Fixing license

  * Adding fetcher and importer

  * Fixing the code
- ✅ Ready to clone and code. [brahle]
- Initial commit. [Bruno Rahle]


